/**
 * apeman tmpl for CI scripts.
 * @memberof module:apeman-tmpl-ci/lib
 * @function load
 * @param {object} params - Template params.
 * @param {string} params.cmd - Name of apeman command.
 * @param {string[]} [params.args] - Command arguments.
 * @param {object} [params.opts] - Command options.
 * @param {string} [mode='644'] - File permission.
 * @param {boolean} [force=false] - Override or not.
 * @returns {object} - Coz bud configuration.
 */

"use strict";

const argx = require('argx'),
    assert = require('assert'),
    fs = require('fs');

/** @lends load */
function load(params, mode, force) {
    let args = argx(arguments);
    params = args.shift('object') || {};

    assert.ok(params.cmd, "params.cmd is required.");
    return {
        force: !!force,
        mode: mode || '755',
        tmpl: fs.readFileSync(__dirname + '/../asset/tmpl.hbs').toString(),
        data: {
            cmd: params.cmd,
            args: [].concat(params.args || []),
            get opts() {
                let opts = params.opts || {};
                return Object.keys(opts).map((key) => {
                    return {key: key, val: opts[key]};
                })
            }
        }
    }
}

module.exports = load;
